function [A, angle, type] = classifyMIN (mu_1,rho_1,a,b,t,set_mu_gamma,print_output)

% returns
%   A : Matrix of basis coefficients [a1,a2,a3]
%
%   type : 
%   Type of minimizer 1 = (I) , 2 = (II) , 3 = (III) , 4 = (IV)
%



type = 0; % either 1,2,3,4 


mu_h = @(b,t) mu_1.*(b./(t+(1-t).*b));  % harmonic mean
mu_bar = @(b,t) mu_1.*((1-t)+t.*b);     % mu_bar

if (set_mu_gamma == 'q1')
  mu_gamma = @(b,t) mu_h(b,t);
end
if (set_mu_gamma == 'q2')
  mu_gamma = @(b,t) mu_bar(b,t);
end
if (set_mu_gamma == 'm')
  mu_gamma = @(b,t) 0.5*(mu_h(b,t) + mu_bar(b,t));
end

%  q1 q2 q3..
q1 = mu_h(b,t);
q2 = mu_bar(b,t); 
q3 = mu_gamma(b,t);




% values for q1,q2,q3 should be positiv
% assert((q1 > 0 ) & (q2 > 0 ) & (q3 > 0), 'At least one of q1,q2 or q3 is not positive' )


% Compute components of B_eff
b1 = (mu_1*rho_1/4).*(b./(t+(1-t).*b)).*(1-t.*(1+a));
b2 =  mu_1.*(rho_1/8).*(1-t.*(1+b.*a));



% H = [q1 q3; q3 q2];          % right ??? 
%check condition of H first
% fprintf('condition number of Matrix H: %d \n', cond(H));




epsilon = 1.e-18;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PARABOLIC CASE  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% if abs(det(A)) < epsilon * min(abs(det(A)),0)  
if abs(q1*q2-q3^2) < epsilon     
    
    fprintf('determinant equal zero (parabolic case)')
    fprintf('SHOULD NOT HAPPEN')
    
    % TODO 
    if ( (b1/b2) - (q3/q1) < epsilon * min((b1/b2),(q3/q1)) )  
        
        %Minimizer not unique
        type = 4;
        % pick one arbitrary Minimzer as output...(TODO)
         a1 = 1; %(TEST)
         a2 = 2; %(TEST) 
    
    else
        % TODO Hier weitere Fallunterscheidung nach b1b2 >0 ,< 0 nötig!
        type = 4; % (TEST)
        a1 = 0*b1; % (TEST)
        a2 = b2; % (TEST)
    end
    
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% ELLIPTIC CASE  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (q1*q2-q3^2 > epsilon)
%     fprintf('determinant greater than zero (elliptic case)');
    
%     a1_star =  (q2(b,t).*q1(b,t).*b1(a,b,t) - q3(b,t).*q2(b,t).*b2(a,b,t))./(q1(b,t).*q2(b,t)-q3(b,t).^2); 
%     a2_star =  (q1(b,t).*q2(b,t).*b2(a,b,t) - q3(b,t).*q1(b,t).*b1(a,b,t))./(q1(b,t).*q2(b,t)-q3(b,t).^2); 
    a1_star =  (q2.*q1.*b1 - q3.*q2.*b2)./(q1.*q2-q3.^2); 
    a2_star =  (q1.*q2.*b2 - q3.*q1.*b1)./(q1.*q2-q3.^2);
    
    prod = a1_star*a2_star;
    
    
    if(prod > epsilon) % (E1)  inside Lamba             %
        % (a1_star,a2_star) is unique minimizer lies inside Lambda 
        % therefore Minimizer not aligned with axes
        
%         fprintf('\n elliptic-case: (E1)');
        a1 = a1_star;
        a2 = a2_star;
        type = 3;
    end
    % Make distinction between boundary & outside (prod < 0 ) 
    if(abs(prod) < epsilon)  % (E2) on boundary of Lambda 
%         fprintf('\n elliptic-case: (E2)');
          
        % Uniqueness of gloal minimizer if lies on boundary  if prod = 0 
        % ----- % 
        

        % global minimizer lies on the boundary of Lambda depending on
        % condition:
        if (q2*b2^2 < q1*b1^2)  % global Minimizer given by (b1,0) 
            a1 = b1;
            a2 = 0*b1;
            type = 1;  % Minimizer aligned with x1-axis
        end
        if  (q2*b2^2 > q1*b1^2)% global Minimizer given by (0,b2)    
            a1 = 0*b1;
            a2 = b2;
            type = 2; % Minimizer aligned with x2-axis
        end
        if abs(q1*b1^2-q2*b2^2) < epsilon * min(q2*b2^2,q1*b1^2) % q1b1^2 = q2b2^2
            % two Minimizers ..pick one
            a1 = b1;
            a2 = 0*b1;
            type = 4;
        end
    end
    if((prod) < -1*epsilon) %Outside of Lambda 
        
        if (q2*b2^2 < q1*b1^2)  % global Minimizer given by (b1,0) 
            a1 = b1;
            a2 = 0*b1;
            type = 1;  % Minimizer aligned with x1-axis
        end
        if  (q2*b2^2 > q1*b1^2)% global Minimizer given by (0,b2)    
            a1 = 0*b1;
            a2 = b2;
            type = 2; % Minimizer aligned with x2-axis
        end
    end
    
end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% HYPERBOLIC CASE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (q1*q2-q3^2 < -1*epsilon) 
%     fprintf('determinant less than zero (hyperbolic case)');
%     
%     if (b1*b2 > 0) % (H1) 
%         % can also be type (I) or (II) 
%         %Minimizer either A1 = (0,b2) or A2 = (b1,0)
%         % needs to be stable
%         
%         
%         % check STABILITY 
%         %check if A2 = (b1,0) is stable
%         if (b1 > 0 && (q3*b1-q2*b2 > 0 )) 
%             a1 = b1;
%             a2 = 0*b2;
%             type = 1;
%         end
%         if (b1 < 0 && (q3*b1-q2*b2 < 0 ) )
%             a1 = b1;
%             a2 = 0*b2;
%             type = 1;
%         end 
%         %check if A1 = (0,b2) is stable 
%          if (b2 > 0 && (q3*b2-q1*b1 > 0 ) )
%             a1 = b1*0;
%             a2 = b2;
%             type = 2;
%         end
%         if (b2 < 0 && (q3*b2-q1*b1 < 0 )  )
%             a1 = b1*0;
%             a2 = b2;
%             type = 2;
%         end 
% 
%     end
%     
%     
%     if ( abs(b1*b2) < epsilon )     %b1*b2 = 0 
%         
%         if (abs(b1) < epsilon )
%             a1 = 0;
%             a2 = b2;
%         else % b2 = 0
%             a1 = b1;
%             a2 = 0; 
%         end
%         
%     end
% 
%     if (b1*b2 < 0)  
%   
%         
%         if (q2*b2^2 < q1*b1^2)  % global Minimizer given by (b1,0) 
%             a1 = b1;
%             a2 = 0*b2;
%             type = 1;  % Minimizer aligned with x1-axis
%         end
%         if  (q2*b2^2 > q1*b1^2)% global Minimizer given by (0,b2)    
%             a1 = 0*b1;
%             a2 = b2;
%             type = 2; % Minimizer aligned with x2-axis
%         end
%         if abs(q1*b1^2-q2*b2^2) < epsilon * min(q2*b2^2,q1*b1^2) % q1b1^2 = q2b2^2
%             % two Minimizers ..pick one
%             a1 = b1;
%             a2 = 0*b1;
%             type = 4;
%         end
%         
%     end

    if (q2*b2^2 < q1*b1^2)  % global Minimizer given by (b1,0) 
        a1 = b1;
        a2 = 0*b1;
        type = 1;  % Minimizer aligned with x1-axis
    end
    if  (q2*b2^2 > q1*b1^2)% global Minimizer given by (0,b2)    
        a1 = 0*b1;
        a2 = b2;
        type = 2; % Minimizer aligned with x2-axis
    end
    if abs(q1*b1^2-q2*b2^2) < epsilon * min(q2*b2^2,q1*b1^2) % q1b1^2 = q2b2^2
        % two Minimizers ..pick one
        a1 = b1;
        a2 = 0*b1;
        type = 4;
    end


    
%     if ( abs(b1*b2) < epsilon)  % b1*b2 = 0 
%     end
    
    
    
    % CAN NOT BE TYPE 3!!
    
end







% Compute a3 from a1 % a2
a3 = sqrt(2*a1*a2);




% compute angle between [sqrt(a1) , sqrt(a2)] and e1:
% angle = atan2(sqrt(a2),sqrt(a1));
if (type == 3 )
   angle = atan2(a2,a1);
else
   angle = 0;
end
% angle = atan2(norm(cross(a,b)), dot(a,b))


%compute Kappa? 
k = sqrt(abs(a1) + abs(a2));  % ? 




% Coefficients of minimizer 

if(print_output)
   fprintf(' \n ') 
   fprintf('=============================== OUTPUT ========================================= \n')
   fprintf('Minimizer is of Type: %d  \n' , type);
   fprintf('Coefficients a1,a2,a3 given by : %d, %d, %d   \n', a1, a2, a3);
   fprintf('================================================================================ \n')
end


A = [a1, a2, a3];



end

